
const SDK = globalThis.SDK;

////////////////////////////////////////////
// The plugin ID is how Construct identifies different kinds of plugins.
// *** NEVER CHANGE THE PLUGIN ID! ***
// If you change the plugin ID after releasing the plugin, Construct will think it is an entirely different
// plugin and assume it is incompatible with the old one, and YOU WILL BREAK ALL EXISTING PROJECTS USING THE PLUGIN.
// Only the plugin name is displayed in the editor, so to rename your plugin change the name but NOT the ID.
// If you want to completely replace a plugin, make it deprecated (it will be hidden but old projects keep working),
// and create an entirely new plugin with a different plugin ID.
const PLUGIN_ID = "ShepherdGames_Rive";
////////////////////////////////////////////

const PLUGIN_CATEGORY = "form-controls";	// The 'Form controls' category is recommended for DOM element plugins

let app = null;

const PLUGIN_CLASS = SDK.Plugins.ShepherdGames_Rive = class MyDrawingPlugin extends SDK.IPluginBase
{
	constructor()
	{
		super(PLUGIN_ID);
		
		SDK.Lang.PushContext("plugins." + PLUGIN_ID.toLowerCase());
		
		this._info.SetName(globalThis.lang(".name"));
		this._info.SetDescription(globalThis.lang(".description"));
		this._info.SetCategory(PLUGIN_CATEGORY);
		this._info.SetAuthor("Shepherd Games");
		this._info.SetHelpUrl(globalThis.lang(".help-url"));
		this._info.SetPluginType("world");			// mark as world plugin since it's placed in the layout
		this._info.SetIsResizable(true);			// allow to be resized
		this._info.SetRuntimeModuleMainScript("c3runtime/main.js");
		
		// Load domSide.js in the document context (main thread).
		// This is important for supporting the runtime's web worker mode.
		this._info.SetDOMSideScripts(["c3runtime/domSide.js"]);
		
		this._info.AddFileDependency({
			filename: "c3runtime/rive.js",
			type: "external-dom-script"
		});
		
		SDK.Lang.PushContext(".properties");
		
		this._info.SetProperties([
			new SDK.PluginProperty("text", "button-text", "Rive Animation"),
			new SDK.PluginProperty("text", "file-path", ""),
			new SDK.PluginProperty("text", "state-machine", "")
		]);
		
		SDK.Lang.PopContext();		// .properties
		
		SDK.Lang.PopContext();
	}
};

PLUGIN_CLASS.Register(PLUGIN_ID, PLUGIN_CLASS);
